# ![Reactotron Logo](./docs/images/readme/Reactotron-128.png)

[![Slack Community](https://infiniteredcommunity.herokuapp.com/badge.svg)](https://infiniteredcommunity.herokuapp.com/)

[Quick Installation Guide](./docs/installing.md)

# What is Reactotron?

Reactotron is a macOS, Windows, and Linux app for inspecting your [React JS](https://facebook.github.io/react/) and [React Native](https://facebook.github.io/react-native/) apps.

*Watch [Darin Wilson's](https://github.com/darinwilson) talk at [Chain React](https://infinite.red/ChainReactConf): [Chain React 2018: Debugging and Beyond with Reactotron](https://www.youtube.com/watch?v=UiPo9A9k7xc)!*

Use it to:

* view your application state
* show API requests & responses
* perform quick performance benchmarks
* subscribe to parts of your application state
* display messages similar to `console.log`
* track global errors with source-mapped stack traces including saga stack traces!
* dispatch actions like a government-run mind control experiment
* hot swap your app's state using Redux or mobx-state-tree
* track your sagas
* show image overlay in React Native
* track your Async Storage in React Native

You plug it into your app as a dev dependency so it adds nothing to your product builds.

### Desktop

 Reactotron on the left, demo React Native app on the right.
 ![Desktop](./docs/images/readme/reactotron-demo-app.gif)

# Documentation

* [Installing](./docs/installing.md)
* Quick start for [React JS](./docs/quick-start-react-js.md)
* Quick start for [React Native](./docs/quick-start-react-native.md)
* [Custom Commands](./docs/custom-commands.md)
* [Tracking errors globally](./docs/plugin-track-global-errors.md)
* [Open in editor](./docs/plugin-open-in-editor.md)
* [Image Overlays](./docs/plugin-overlay.md)
* [Async Storage](./docs/plugin-async-storage.md)
* [Networking](./docs/plugin-networking.md)
* [Benchmarking](./docs/plugin-benchmark.md)
* Integrating with [mobx-state-tree](./docs/plugin-mst.md)
* Integrating with [Redux](./docs/plugin-redux.md)
* Integrating with [Redux Saga](./docs/plugin-redux-saga.md)
* Networking monitoring with [Apisauce](./docs/plugin-apisauce.md)
* [Storybook (React Native Only)](./docs/plugin-storybook.md)
* [Troubleshooting](./docs/troubleshooting.md)
* [Tips and Tricks](./docs/tips.md)
* [Release Notes](https://github.com/reactotron/reactotron/releases)
* [Contributing](./docs/contributing.md)

# Credits

Reactotron is developed by [Infinite Red](https://infinite.red), [@rmevans9](https://github.com/rmevans9), and 70+ amazing contributors! Special thanks to [@skellock](https://github.com/skellock) for originally creating Reactotron while at Infinite Red.

# Premium Support

 [Reactotron](https://infinite.red/reactotron), as an open source project, is free to use and always will be. [Infinite Red](https://infinite.red/) offers premium React and [React Native](https://infinite.red/react-native) mobile app design/development services. Email us at [hello@infinite.red](mailto:hello@infinite.red) to get in touch for more details.
